==> haskell-text-builder-0.6.6.1-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-builder
version:              0.6.6.1
visibility:           public
id:                   text-builder-0.6.6.1-Fi2kIo8ZUtuDjyD3wM3KHi
key:                  text-builder-0.6.6.1-Fi2kIo8ZUtuDjyD3wM3KHi
license:              MIT
copyright:            (c) 2017, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/text-builder
synopsis:             An efficient strict text builder
category:             Text
abi:                  94c899ba78ce84943b66c992d0edd374
exposed:              True
exposed-modules:      Text.Builder
hidden-modules:       Text.Builder.UTF16 Text.Builder.Prelude
import-dirs:          /usr/lib/ghc-8.8.3/site-local/text-builder-0.6.6.1
library-dirs:         /usr/lib/ghc-8.8.3/site-local/text-builder-0.6.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/text-builder-0.6.6.1
hs-libraries:         HStext-builder-0.6.6.1-Fi2kIo8ZUtuDjyD3wM3KHi
depends:
    base-4.13.0.0 bytestring-0.10.10.0
    deferred-folds-0.9.10.1-6cZhyhUkHBY7PUkpjNcK23 text-1.2.4.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-text-builder/html/text-builder.haddock

haddock-html:         /usr/share/doc/haskell-text-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-builder-0.6.6.1-27-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-builder
version:              0.6.6.1
visibility:           public
id:                   text-builder-0.6.6.1-AAWeYNHS4lvCCxLoX7yUhq
key:                  text-builder-0.6.6.1-AAWeYNHS4lvCCxLoX7yUhq
license:              MIT
copyright:            (c) 2017, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/text-builder
synopsis:             An efficient strict text builder
category:             Text
abi:                  f8dbf8040cd4a7b52c86b1fa5d57016d
exposed:              True
exposed-modules:      Text.Builder
hidden-modules:       Text.Builder.UTF16 Text.Builder.Prelude
import-dirs:          /usr/lib/ghc-8.8.3/site-local/text-builder-0.6.6.1
library-dirs:         /usr/lib/ghc-8.8.3/site-local/text-builder-0.6.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/text-builder-0.6.6.1
hs-libraries:         HStext-builder-0.6.6.1-AAWeYNHS4lvCCxLoX7yUhq
depends:
    base-4.13.0.0 bytestring-0.10.10.0
    deferred-folds-0.9.10.1-IOxWJjzxF3wDJfs2C4oju0 text-1.2.4.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-text-builder/html/text-builder.haddock

haddock-html:         /usr/share/doc/haskell-text-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
